#!/usr/bin/env python

from distutils.core import setup
import os
import glob
import sys

name = "gnome-fix-broken-links"
version = file(os.path.join(os.path.dirname(sys.argv[1]),"version")).read().strip()

setup(name=name,
	version=version,
	description="Fix broken links by finding targets with Beagle",
	long_description="This tiny tool lets you fix broken links by automatically querying Beagle to find possible targets for dangling symlinks.",
	author="Manuel Amador (Rudd-O)",
	author_email="rudd-o@amautacorp.com",
	url="http://www.amautacorp.com/staff/Rudd-O/",
	scripts=["gnome-fix-broken-links"],
	data_files=[('share/gnome-fix-broken-links', 
['gnome-fix-broken-links.glade','version'])]
	)
